@@ -1,7 +1,10 @@
 import logging
+import os.path
 from functools import reduce
 from itertools import groupby
 from typing import List, Dict, Union
+import inspect
+from importlib.util import spec_from_file_location, module_from_spec
 
 
 def list_dict_group(data: List[Dict], key):
@@ -120,3 +123,29 @@ def check_or_add_growth_rate(data: List[dict], value_key: str, growth_rate_key:
                 if digits:
                     value = round(value, digits)
                 data[i][growth_rate_key] = value
+
+
+def get_members_from_file(file_path: str, name="module"):
+    if os.path.exists(file_path):
+        spec = spec_from_file_location(name, file_path)
+        module = module_from_spec(spec)
+        spec.loader.exec_module(module)
+        members = inspect.getmembers(module, lambda member: not inspect.ismodule(member))
+        members_list = []
+        for name, value in members:
+            if not name.startswith('_'):
+                info = {"name": name, "value": value}
+                if inspect.isclass(value):
+                    info["type"] = "class"
+                    class_members = []
+                    for k, v in vars(value).items():
+                        if not k.startswith("_"):
+                            class_member_info = {"name": k, "value": v, "type": v.__class__.__name__}
+                            class_members.append(class_member_info)
+                    info["class_members"] = class_members
+                else:
+                    info["type"] = value.__class__.__name__
+                members_list.append(info)
+        return members_list
+    else:
+        raise Exception(f"file_path={file_path} not exist")
